@@ -56,9 +56,7 @@ test_that("best_l works", {
   set.seed(1)
   l1 <- best_l(img_2ch, purpose = "fcs")
   expect_equal(length(l1), 2)
-  set.seed(1)
-  l2 <- best_l(img_2ch, purpose = "fcs")
-  expect_equal(l1, l2)
+  expect_equal(mean(l1), 17, tolerance = 2)
   set.seed(4)
   img <- array(rpois(99^3, 99), dim = rep(99, 3))
   bt <- round(best_tau(img, purpose = "ffs"))
@@ -93,12 +91,9 @@ test_that("best_degree works", {
   best_degree <- suppressWarnings(round(best_degree(img, purpose = "ffs")))
   expect_equal(best_degree, 17, tolerance = 2)
   img_2ch <- abind::abind(img, img, along = 3)
-  set.seed(1)
   d1 <- suppressWarnings(best_degree(img_2ch, purpose = "fcs"))
   expect_equal(length(d1), 2)
-  set.seed(1)
-  d2 <- suppressWarnings(best_degree(img_2ch, purpose = "fcs"))
-  expect_equal(d1, d2)
+  expect_equal(mean(d1), 17, tolerance = 2)
   set.seed(7)
   img <- array(rpois(99^3, 99), dim = rep(99, 3))
   best_degree <- suppressWarnings(round(best_degree(img, purpose = "ffs")))
